@@ -1,6 +1,5 @@
 import enum
 import inspect
-import logging
 import math
 import sys
 from collections import namedtuple
@@ -12,7 +11,6 @@ from bravado.exception import HTTPNotFound
 from django.contrib.staticfiles.storage import staticfiles_storage
 from django.db import models
 
-from . import __title__, constants
 from .app_settings import (
     EVEUNIVERSE_LOAD_ASTEROID_BELTS,
     EVEUNIVERSE_LOAD_DOGMAS,
@@ -26,7 +24,8 @@ from .app_settings import (
     EVEUNIVERSE_LOAD_TYPE_MATERIALS,
     EVEUNIVERSE_USE_EVESKINSERVER,
 )
-from .core import eveimageserver, eveskinserver, fuzzwork
+from .constants import EveCategoryId, EveGroupId
+from .core import eveimageserver, evemicros, eveskinserver
 from .managers import (
     EveAsteroidBeltManager,
     EveEntityManager,
@@ -41,9 +40,6 @@ from .managers import (
     EveUniverseEntityModelManager,
 )
 from .providers import esi
-from .utils import LoggerAddTag
-
-logger = LoggerAddTag(logging.getLogger(__name__), __title__)
 
 NAMES_MAX_LENGTH = 100
 
@@ -1199,29 +1195,39 @@ class EveSolarSystem(EveUniverseEntityModel):
         except HTTPNotFound:
             return None
 
-    def nearest_celestial(self, x: int, y: int, z: int) -> Optional[NearestCelestial]:
-        """Return nearest celestial to given coordinates as eveuniverse object.
+    def nearest_celestial(
+        self, x: int, y: int, z: int, group_id: int = None
+    ) -> Optional[NearestCelestial]:
+        """Determine nearest celestial to given coordinates as eveuniverse object.
 
-        Will return None if none is found.
+        Args:
+            x, y, z: Start point in space to look from
+            group_id: Eve ID of group to filter results by
+
+        Raises:
+            HTTPError: If an HTTP error is encountered
+
+        Returns:
+            Eve item or None if none is found
         """
-        item = fuzzwork.nearest_celestial(x, y, z, solar_system_id=self.id)
+        item = evemicros.nearest_celestial(
+            solar_system_id=self.id, x=x, y=y, z=z, group_id=group_id
+        )
         if not item:
             return None
-
         eve_type, _ = EveType.objects.get_or_create_esi(id=item.type_id)
-        if eve_type.eve_group_id == constants.EVE_GROUP_ID_ASTEROID_BELT:
+        if eve_type.eve_group_id == EveGroupId.ASTEROID_BELT:
             MyClass = EveAsteroidBelt
-        elif eve_type.eve_group_id == constants.EVE_GROUP_ID_MOON:
+        elif eve_type.eve_group_id == EveGroupId.MOON:
             MyClass = EveMoon
-        elif eve_type.eve_group_id == constants.EVE_GROUP_ID_PLANET:
+        elif eve_type.eve_group_id == EveGroupId.PLANET:
             MyClass = EvePlanet
-        elif eve_type.eve_group_id == constants.EVE_GROUP_ID_STARGATE:
+        elif eve_type.eve_group_id == EveGroupId.STARGATE:
             MyClass = EveStargate
-        elif eve_type.eve_group_id == constants.EVE_GROUP_ID_STATION:
+        elif eve_type.eve_group_id == EveGroupId.STATION:
             MyClass = EveStation
         else:
             return None
-
         obj, _ = MyClass.objects.get_or_create_esi(id=item.id)
         return self.NearestCelestial(
             eve_type=eve_type, eve_object=obj, distance=item.distance
@@ -1495,10 +1501,10 @@ class EveType(EveUniverseEntityModel):
             if not category_id:
                 category_id = self.eve_group.eve_category_id
 
-            if category_id == constants.EVE_CATEGORY_ID_BLUEPRINT:
+            if category_id == EveCategoryId.BLUEPRINT:
                 variant = self.IconVariant.BPO
 
-            elif category_id == constants.EVE_CATEGORY_ID_SKIN:
+            elif category_id == EveCategoryId.SKIN:
                 variant = self.IconVariant.SKIN
 
         if variant is self.IconVariant.BPO:
